# Bachelor Thesis MATLAB Files

This repository contains the MATLAB scripts from the bachelor thesis *Blind
Source Separation with Beamforming*.

The MATLAB workspace should be initialized in this directory using the command
`setupPath` which adds all subfolders to the MATLAB path. Running `main`
performs that automatically and all early stage simulations.

## Subdirectories

| Directory     | Description                                                 |
|---------------|-------------------------------------------------------------|
| `beamforming` | Beamforming-only scripts (without relation to BSS)          |
| `contributed` | Third-party source code that was obtained from the internet |
| `framework`   | Evaluation scripts for different indoor environments        |
| `resources`   | Scripts to generate figures for the thesis                  |
| `test`        | Scratchpads and code in very early stage                    |
| `util`        | Utilities like file I/O, noise generation, ...              |
| `wav`         | Wave audio files (sample speech signals & recordings)       |

## MATLAB Classes

| Class        | Description                                      |
|--------------|--------------------------------------------------|
| `Beamformer` | Beamforming algorithms                           |
| `Noise`      | Noise generation (white, pink, ...)              |
| `STFT`       | Short-Time Fourier Transform (also plot methods) |

The scripts `test{Beamformer,Noise,STFT}.m` provide test cases for each class.

## Main algorithms

| File      | Algorithm                                                    |
|-----------|--------------------------------------------------------------|
| `infomax` | Infomax implementation (not documented in the thesis)        |
| `permutationAlignmentDyadic`  | Permutation alignment by dyadic sorting  |
| `permutationAlignmentRegions` | Permutation alignment by growing regions |

FastICA was contributed by the `pca_ica` package.

## Naming of Scripts

The remaining scripts show a consistent naming scheme:

1. Type of the mixture (linear or convolutive)
2. Type of source signals (artificial or speech)
3. Optional pre-processing stages (Beamforming, PCA, ...)
4. Main algorithm (FastICA, frequency-domain FastICA, Infomax, ...)
5. Additional features (real-world, plots, additional noise, ...)

Except for the `targetSpeechExtraction*.m` scripts that feature a special setup
of one target source in an underdetermined system.

See also the file `INDEX.md`.

## Contact

Marvin Klimke <marvin.klimke@rwth-aachen.de>
